import React, { useEffect, useState, useRef } from 'react';
import { View, Text, StyleSheet, ActivityIndicator, Image, TouchableOpacity, Animated, Easing, Dimensions } from 'react-native';

// AdMob-like ad types
export enum AdType {
  INTERSTITIAL = 'interstitial',
  BANNER = 'banner',
  REWARDED = 'rewarded'
}

interface AdDisplayProps {
  onAdComplete: () => void;
  durationInSeconds?: number;
  adType?: AdType;
  isVideoAd?: boolean;
  showSkipButton?: boolean;
}

// Real AdMob IDs for different ad formats
const AD_UNIT_IDS = {
  INTERSTITIAL: 'ca-app-pub-3808259283882168/9569773803', // Real Rewarded Ad ID
  BANNER: 'ca-app-pub-3808259283882168/9569773803', // Using rewarded ad ID for now
  REWARDED: 'ca-app-pub-3808259283882168/9569773803' // Real Rewarded Ad ID
};

// App ID: ca-app-pub-3808259283882168~6546457972

// Mock ad content
const AD_CONTENT = [
  {
    title: 'ألعاب مجانية',
    message: 'قم بتنزيل أفضل ألعاب العام على متجر بلاي!',
    cta: 'تحميل الآن'
  },
  {
    title: 'عروض خاصة',
    message: 'خصومات حصرية على المنتجات الرياضية',
    cta: 'تسوق الآن'
  },
  {
    title: 'تطبيقات مميزة',
    message: 'اكتشف أفضل التطبيقات الجديدة',
    cta: 'اكتشف المزيد'
  },
  {
    title: 'الأفلام الجديدة',
    message: 'شاهد أحدث الأفلام العالمية',
    cta: 'شاهد الآن'
  }
];

const { width: SCREEN_WIDTH } = Dimensions.get('window');

const AdDisplay = ({ 
  onAdComplete, 
  durationInSeconds = 5, 
  adType = AdType.INTERSTITIAL,
  isVideoAd = false,
  showSkipButton = true
}: AdDisplayProps) => {
  const [timeRemaining, setTimeRemaining] = useState(durationInSeconds);
  const [adLoaded, setAdLoaded] = useState(false);
  const [currentAd] = useState(AD_CONTENT[Math.floor(Math.random() * AD_CONTENT.length)]);
  const fadeAnim = useRef(new Animated.Value(0)).current;
  const loadingProgress = useRef(new Animated.Value(0)).current;
  
  // Simulate ad loading
  useEffect(() => {
    // Start with loading animation
    Animated.timing(loadingProgress, {
      toValue: 1,
      duration: 1500,
      useNativeDriver: false,
      easing: Easing.ease
    }).start(() => {
      // Then fade in the ad
      setAdLoaded(true);
      Animated.timing(fadeAnim, {
        toValue: 1,
        duration: 500,
        useNativeDriver: true
      }).start();
    });
    
    // Clean up animations
    return () => {
      loadingProgress.resetAnimation();
      fadeAnim.resetAnimation();
    };
  }, []);
  
  // Countdown timer for ad
  useEffect(() => {
    if (!adLoaded) return;
    
    const timer = setInterval(() => {
      setTimeRemaining((prev) => {
        if (prev <= 1) {
          clearInterval(timer);
          onAdComplete();
          return 0;
        }
        return prev - 1;
      });
    }, 1000);
    
    return () => clearInterval(timer);
  }, [adLoaded, durationInSeconds, onAdComplete]);
  
  // Skip button only appears after a few seconds for interstitial ads
  const [canSkip, setCanSkip] = useState(!showSkipButton);
  
  useEffect(() => {
    if (showSkipButton && adType === AdType.INTERSTITIAL) {
      const skipTimer = setTimeout(() => {
        setCanSkip(true);
      }, 2000); // Show skip after 2 seconds
      
      return () => clearTimeout(skipTimer);
    }
  }, [showSkipButton, adType]);
  
  // Loading screen
  if (!adLoaded) {
    return (
      <View style={styles.container}>
        <View style={styles.loadingContainer}>
          <Text style={styles.loadingText}>جاري تحميل الإعلان...</Text>
          <Animated.View 
            style={[
              styles.progressBar, 
              { width: loadingProgress.interpolate({
                inputRange: [0, 1],
                outputRange: ['0%', '100%']
              })}
            ]} 
          />
        </View>
      </View>
    );
  }
  
  // Video ad style (fullscreen with video-like content)
  if (isVideoAd) {
    return (
      <Animated.View style={[styles.container, { opacity: fadeAnim }]}>
        <View style={styles.videoAdContainer}>
          <View style={styles.adHeader}>
            <Text style={styles.adTitle}>إعلان فيديو</Text>
            {canSkip && (
              <TouchableOpacity style={styles.skipButton} onPress={onAdComplete}>
                <Text style={styles.skipText}>تخطي</Text>
              </TouchableOpacity>
            )}
          </View>
          
          <View style={styles.videoAdContent}>
            <ActivityIndicator size="large" color="#E50914" style={styles.videoPlayIcon} />
            <Text style={styles.videoAdTitle}>{currentAd.title}</Text>
            <Text style={styles.videoAdMessage}>{currentAd.message}</Text>
          </View>
          
          <View style={styles.adFooter}>
            <Text style={styles.timerText}>
              {timeRemaining} ثانية متبقية...
            </Text>
            <TouchableOpacity style={styles.ctaButton}>
              <Text style={styles.ctaText}>{currentAd.cta}</Text>
            </TouchableOpacity>
          </View>
        </View>
      </Animated.View>
    );
  }
  
  // Regular interstitial ad
  return (
    <Animated.View style={[styles.container, { opacity: fadeAnim }]}>
      <View style={styles.adContainer}>
        <View style={styles.adHeader}>
          <Text style={styles.adTitle}>إعلان</Text>
          {canSkip && (
            <TouchableOpacity style={styles.skipButton} onPress={onAdComplete}>
              <Text style={styles.skipText}>تخطي</Text>
            </TouchableOpacity>
          )}
        </View>
        
        <View style={styles.adContentPlaceholder}>
          <Text style={styles.adText}>{currentAd.title}</Text>
          <Text style={styles.adSubtext}>{currentAd.message}</Text>
          <TouchableOpacity style={styles.ctaButton}>
            <Text style={styles.ctaText}>{currentAd.cta}</Text>
          </TouchableOpacity>
        </View>
        
        <View style={styles.timerContainer}>
          <Text style={styles.timerText}>
            الفيديو سيبدأ خلال {timeRemaining} ثانية
          </Text>
          <ActivityIndicator size="small" color="#E50914" />
        </View>
      </View>
    </Animated.View>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: '#121212',
  },
  adContainer: {
    width: '90%',
    height: '80%',
    backgroundColor: '#1E1E1E',
    borderRadius: 8,
    overflow: 'hidden',
    elevation: 5,
    shadowColor: '#000',
    shadowOffset: { width: 0, height: 2 },
    shadowOpacity: 0.3,
    shadowRadius: 4,
  },
  adHeader: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    backgroundColor: '#E50914',
  },
  adTitle: {
    color: 'white',
    padding: 8,
    fontWeight: 'bold',
    flex: 1,
    textAlign: 'center',
  },
  skipButton: {
    paddingHorizontal: 12,
    paddingVertical: 6,
    backgroundColor: 'rgba(0,0,0,0.5)',
    borderRadius: 4,
    margin: 4,
  },
  skipText: {
    color: 'white',
    fontWeight: 'bold',
  },
  adContentPlaceholder: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    padding: 20,
  },
  adText: {
    color: 'white',
    fontSize: 24,
    fontWeight: 'bold',
    marginBottom: 10,
    textAlign: 'center',
  },
  adSubtext: {
    color: '#AAAAAA',
    textAlign: 'center',
    marginBottom: 20,
  },
  timerContainer: {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
    padding: 10,
    backgroundColor: 'rgba(0,0,0,0.7)',
  },
  timerText: {
    color: 'white',
    marginRight: 10,
  },
  // Loading styles
  loadingContainer: {
    width: '80%',
    padding: 20,
    backgroundColor: '#1E1E1E',
    borderRadius: 8,
    alignItems: 'center',
  },
  loadingText: {
    color: 'white',
    marginBottom: 15,
    fontWeight: 'bold',
  },
  progressBar: {
    height: 6,
    backgroundColor: '#E50914',
    borderRadius: 3,
    alignSelf: 'stretch',
  },
  // Video ad styles
  videoAdContainer: {
    width: SCREEN_WIDTH,
    height: '100%',
    backgroundColor: '#1E1E1E',
  },
  videoAdContent: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    padding: 20,
    backgroundColor: '#000',
  },
  videoPlayIcon: {
    marginBottom: 20,
  },
  videoAdTitle: {
    color: 'white',
    fontSize: 26,
    fontWeight: 'bold',
    marginBottom: 15,
    textAlign: 'center',
  },
  videoAdMessage: {
    color: 'white',
    fontSize: 18,
    textAlign: 'center',
    marginBottom: 20,
  },
  adFooter: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    padding: 15,
    backgroundColor: 'rgba(0,0,0,0.8)',
  },
  ctaButton: {
    backgroundColor: '#E50914',
    paddingHorizontal: 16,
    paddingVertical: 8,
    borderRadius: 4,
    marginTop: 10,
  },
  ctaText: {
    color: 'white',
    fontWeight: 'bold',
  },
});

export default AdDisplay;