import React, { useEffect } from 'react';
import { 
  StyleSheet, 
  View, 
  Text, 
  TouchableOpacity, 
  ScrollView, 
  Image, 
  Linking,
  StatusBar
} from 'react-native';
import { NativeStackScreenProps } from '@react-navigation/native-stack';
import { RootStackParamList } from '../../App';

type HomeScreenProps = NativeStackScreenProps<RootStackParamList, 'Home'>;

export default function HomeScreen({ navigation }: HomeScreenProps) {
  useEffect(() => {
    // This effect will run on component mount, checking if we were opened via deep link
    // We'll handle direct deep links in the App.tsx, but this is a fallback
    
    const getInitialURL = async () => {
      try {
        const url = await Linking.getInitialURL();
        if (url) {
          // If the app was opened via a deep link, we might already navigate to the player
          // in App.tsx, but this is a fallback
          handleDeepLink(url);
        }
      } catch (e) {
        console.error('Error getting initial URL', e);
      }
    };
    
    getInitialURL();
    
    // Subscribe to deep link events
    const subscription = Linking.addEventListener('url', ({ url }) => {
      handleDeepLink(url);
    });
    
    return () => {
      subscription.remove();
    };
  }, [navigation]);
  
  const handleDeepLink = (url: string) => {
    // Parse the URL to extract params
    try {
      const { path, queryParams } = Linking.parse(url);
      
      if (path === 'play' && queryParams.videoUrl) {
        navigation.navigate('Player', {
          videoUrl: String(queryParams.videoUrl),
          title: queryParams.title ? String(queryParams.title) : undefined,
          thumbnail: queryParams.thumbnail ? String(queryParams.thumbnail) : undefined,
          contentType: queryParams.contentType as any
        });
      }
    } catch (e) {
      console.error('Error parsing deep link', e);
    }
  };
  
  const openSaqrTV = async () => {
    try {
      // Try to open Saqr TV app
      const supported = await Linking.canOpenURL('saqrtv://');
      
      if (supported) {
        await Linking.openURL('saqrtv://');
      } else {
        // If not installed, open Google Play Store
        await Linking.openURL(
          'https://play.google.com/store/apps/details?id=com.saqrtv.app'
        );
      }
    } catch (e) {
      console.error('Error opening Saqr TV app', e);
    }
  };
  
  return (
    <View style={styles.container}>
      <StatusBar barStyle="light-content" backgroundColor="#121212" />
      <ScrollView contentContainerStyle={styles.contentContainer}>
        <View style={styles.header}>
          <View style={styles.logoContainer}>
            <Text style={styles.logoText}>S</Text>
          </View>
          <Text style={styles.title}>صقر بلاير</Text>
        </View>
        
        <Text style={styles.description}>
          مشغل الفيديو المتطور مع دعم لمختلف تنسيقات الفيديو وميزات متقدمة للتحكم في التشغيل.
        </Text>
        
        <View style={styles.infoContainer}>
          <Text style={styles.infoTitle}>كيفية الاستخدام</Text>
          <Text style={styles.infoText}>
            1. افتح تطبيق صقر تي في واختر المحتوى الذي ترغب بمشاهدته
          </Text>
          <Text style={styles.infoText}>
            2. اضغط على زر التشغيل وسيتم فتح صقر بلاير تلقائيًا
          </Text>
          <Text style={styles.infoText}>
            3. استمتع بمشاهدة المحتوى بجودة عالية
          </Text>
        </View>
        
        <View style={styles.featuresContainer}>
          <Text style={styles.featuresTitle}>المميزات</Text>
          <View style={styles.featuresList}>
            <FeatureItem 
              title="دعم جميع التنسيقات" 
              description="تشغيل جميع أنواع ملفات الفيديو بكفاءة عالية" 
            />
            <FeatureItem 
              title="تحكم كامل" 
              description="أدوات متقدمة للتحكم في التشغيل والإيقاف المؤقت" 
            />
            <FeatureItem 
              title="وضع ملء الشاشة" 
              description="مشاهدة الفيديو بكامل الشاشة للحصول على أفضل تجربة" 
            />
            <FeatureItem 
              title="متوافق مع صقر تي في" 
              description="مصمم خصيصًا للعمل مع تطبيق صقر تي في" 
            />
          </View>
        </View>
        
        <TouchableOpacity style={styles.tvAppButton} onPress={openSaqrTV}>
          <Text style={styles.tvAppButtonText}>فتح تطبيق صقر تي في</Text>
        </TouchableOpacity>
      </ScrollView>
    </View>
  );
}

interface FeatureItemProps {
  title: string;
  description: string;
}

const FeatureItem = ({ title, description }: FeatureItemProps) => (
  <View style={styles.featureItem}>
    <Text style={styles.featureTitle}>{title}</Text>
    <Text style={styles.featureDescription}>{description}</Text>
  </View>
);

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#121212',
  },
  contentContainer: {
    padding: 20,
    alignItems: 'center',
  },
  header: {
    flexDirection: 'row',
    alignItems: 'center',
    marginBottom: 20,
  },
  logoContainer: {
    width: 50,
    height: 50,
    borderRadius: 25,
    backgroundColor: '#E50914',
    justifyContent: 'center',
    alignItems: 'center',
    marginRight: 10,
  },
  logoText: {
    color: 'white',
    fontSize: 24,
    fontWeight: 'bold',
  },
  title: {
    fontSize: 28,
    fontWeight: 'bold',
    color: 'white',
  },
  description: {
    fontSize: 16,
    color: '#AAAAAA',
    textAlign: 'center',
    marginBottom: 30,
  },
  infoContainer: {
    width: '100%',
    backgroundColor: '#1E1E1E',
    borderRadius: 8,
    padding: 15,
    marginBottom: 20,
  },
  infoTitle: {
    fontSize: 18,
    fontWeight: 'bold',
    color: 'white',
    marginBottom: 10,
    textAlign: 'right',
  },
  infoText: {
    fontSize: 14,
    color: '#DDDDDD',
    marginBottom: 8,
    textAlign: 'right',
  },
  featuresContainer: {
    width: '100%',
    marginBottom: 30,
  },
  featuresTitle: {
    fontSize: 18,
    fontWeight: 'bold',
    color: 'white',
    marginBottom: 15,
    textAlign: 'right',
  },
  featuresList: {
    width: '100%',
  },
  featureItem: {
    backgroundColor: '#1E1E1E',
    borderRadius: 8,
    padding: 15,
    marginBottom: 10,
  },
  featureTitle: {
    fontSize: 16,
    fontWeight: 'bold',
    color: 'white',
    marginBottom: 5,
    textAlign: 'right',
  },
  featureDescription: {
    fontSize: 14,
    color: '#AAAAAA',
    textAlign: 'right',
  },
  tvAppButton: {
    backgroundColor: '#E50914',
    paddingVertical: 12,
    paddingHorizontal: 30,
    borderRadius: 8,
    width: '80%',
  },
  tvAppButtonText: {
    color: 'white',
    fontSize: 16,
    fontWeight: 'bold',
    textAlign: 'center',
  },
});